<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="mn">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Проксины төрөл</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Хаяг</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Шаардлаггүй</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Цуцлах</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Хадгалах</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Салгах</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Устгах</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Цуцлах</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Хадгалах</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Холбогдож байна</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Салгах</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Утастай холболт %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Утасгүй сүлжээ цацагч</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE холболт %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Шинэ VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Хийсвэр Хувийн Сүлжээний Төрөл</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Сүлжээ</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Сүлжээний дэлгэрэнгүй мэдээлэл</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системийн прокси</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Утастай сүлжээ</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Утасгүй сүлжээ</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Сүлжээний холболт нэмэх</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Нуужуулсан сүлжээнд холбогдоно уу</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE холболт үүсгэх</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN-ний төлөв</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN үүсгэх</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Импорт VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Проксины төрөл</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Тохиргооны URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Хаяг</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Утасгүй сүлжээ цацагч</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфэйс</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Холболт</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Үндсэн DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Нэтмаск</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Угтвар</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Хурд</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Итернэт</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Бэхлэгдээгүй</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Төхөөрөмжийн МАК хаяг</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Хувилсан МАК хаяг</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU өөрчлөх</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Ерөнхий</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Ерөнхий</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Нэр</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Утасгүй сүлжээ цацагч</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Тохиргоо нэмэх</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Хаяг</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Нэтмаск</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Угтвар</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автомат</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Гар арга</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Орхих</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Хаяг</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Зөвхөн холбогдох нөөцөд л хамаарна</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Арга</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Нэтмаск</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Угтвар</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Сүлжээ</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Арга</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автомат</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Гар арга</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Орхих</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Сүлжээний дэлгэрэнгүй мэдээлэл</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системийн прокси</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Сүлжээний дэлгэрэнгүй мэдээлэл</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сүлжээ</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Идэвхигүй болсон</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Гар арга</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автомат</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Үйлчилгээ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD өгөгдлийн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate өгөгдлийн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP толгойн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Портколын талбарын шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Хаяггүй/Хяналтын шахалт</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP цуурай багц илгээх</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE хэрэглэх</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128 бит MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE холболт үүсгэх</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Системийн прокси</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Цуцлах</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Хадгалах</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Проксины төрөл</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Гар арга</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автомат</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Шаардлаггүй</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP прокси</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS прокси</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP прокси</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS прокси</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Дээрх талбарт бичигдсэн хостууд болон домайнуудад прокси тохиргоо хамааралгүй.</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Тохиргооны URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Аюулгүй байдал</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Protected EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Идэвхигүй болсон</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Нэргүй</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Баталгаажсан</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Аль аль нь</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматаар</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Хувилбар 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Хувилбар 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Тодорхойлолт</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd сонголтууд</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Хувийн түлхүүр</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA гэрчилгээ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Хэрэглэгчийн гэрчилгээ</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Нэргүй ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Төлөвлөлт</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC файл</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP хувилбар</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Хувийн Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Байхгүй</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 хувийн</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Аюулгүй байдал</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Түлхүүр</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Аюулгүй байдал шаардлагатай</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Байхгүй</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 хувийн</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>Аж ахуй нэгжийн WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Аюулгүй байдал</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>Түлхүүр</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation> VPN нарийвчилсан тохиргоо</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Гарцын портыг тохируулах</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Гарцын порт</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Дахин нийцүүлэх давтамж тохируулах</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Дахин нийцүүлэх давтамж</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>MTU туннель тохируулах</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP хэсгийн хэмжээ тохируулах</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP хэсгийн хэмжээ</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>TCP MSS Туннел хязгаарлах</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Алсын хостыг эрэмбэлэх</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation> VPN нарийвчилсан тохиргоо</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Сиско (үндсэн)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Нэтскрийн</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Нууцлалтай (үндсэн)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Сул</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Байхгүй</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T боломжтой үед (үндсэн)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Үргэлж NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Сиско UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Идэвхигүй болсон</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH групп 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH групп 2 (үндсэн)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH групп 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сервер (үндсэн)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH групп 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домэйн</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Борлуулагч</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Хувилбар</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Шифрлэлт</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal горим</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH групп</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Урд талын нууцлал</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Дотоод порт</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Dead Peer Detection-г идэвхгүй болгох</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec идэвхижүүлэх</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Группийн нэр</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Группийн ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Хуваалцахын өмнөх түлхүүр</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>1-р үелэлийн алгоритм</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>2-р үелэлийн алгоритм</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA гэрчилгээ</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Сискогийн десктопын трожан нууцлалыг зөвшөөрөх</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD скрипт</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Хэрэглэгчийн гэрчилгээ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Хувийн түлхүүр</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>FSID түлхүүр нууц үгт ашиглах</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Гэрчилгээ (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Нууц үгтэй гэрчилгээ (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статик түлхүүр</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Хадгалсан</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Асуух</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Шаардлагагүй</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Зөвшөөрөлийн төрөл</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA гэрчилгээ</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Хэрэглэгчийн гэрчилгээ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Хувийн түлхүүр</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd сонголтууд</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Хувийн Pwd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Түлхүүрийн чиглэлийг өөрчлөх</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Түлхүүрийн чиглэл</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Алсын IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Дотоод IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Бүгд боломжтой (үндсэн)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-бит (нууцлал бага)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-бит (нууцлал өндөр)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 баталгаажуулалтаас татгалзах</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD өгөгдлийн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflate өгөгдлийн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP толгойн шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Портколын талбарын шахалт байхгүй</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Хаяггүй/Хяналтын шахалт</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP цуурай багц илгээх</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE хэрэглэх</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Аюулгүй байдал</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN-ний төлөв</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN үүсгэх</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Импорт VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Импортын алдаа</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>ЗА</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN прокси</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Шаардлагагүй</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Проксины төрөл</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Серверийн IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Тодорхойгүй шалтгаанаар амжилгүй болвол дахин оролдож үзнэ үү</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA файл</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN аюулгүй байдал</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Үндсэн</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Байхгүй</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифр</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Хадгалсан</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Асуух</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Шаардлагагүй</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd сонголтууд</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT домэйн</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN прокси</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Серверийн IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Хувийн түлхүүр</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH агент</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Хуваалцахын өмнөх түлхүүр</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA гэрчилгээ</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Зөвшөөрөлийн төрөл</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Хэрэглэгчийн гэрчилгээ</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Дотоод IP хаягийн хүсэлт гаргах</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP хайрцаглалтыг мөрдөх</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP шахагчыг хэрэглэх</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS баталгаажуулалт</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Үндсэн</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Харилцагч</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Субжект тэнцэл</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Алсын гэрчилгээний төрөл</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Түлхүүр файл</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Түлхүүрийн чиглэлийг өөрчлөх</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Түлхүүрийн чиглэл</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Хадгалсан</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Асуух</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Шаардлагагүй</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Шаардлагатай</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Хэрэглэгчийн нэр</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd сонголтууд</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Нууц үг</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Группийн нэр</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Групп Pwd</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Эрлийз баталгаажуулалт ашиглах</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA файл</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Сүлжээний холболт нэмэх</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Тохиргоо сонгох</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Нуужуулсан сүлжээнд холбогдоно уу</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Бэхлэгдээгүй</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Төхөөрөмжийн МАК хаяг</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU өөрчлөх</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Утасгүй сүлжээ цацагч</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>Суваг</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Холболт</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфэйс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАК</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Нэтмаск</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Гарц</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Үндсэн DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Угтвар</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Хурд</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Төхөөрөмж идэвхгүй болсон</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Холбогдсон боловч интернетэд холбогдоогүй байна</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Холбогдоогүй</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сүлжээний кабель салгагдсан</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Холбогдож байна</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Баталгаажуулж байна</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Хаягыг авч байна</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Холбогдсон</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Холболт тасарсан</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Амжилтгүй болсон</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Утастай сүлжээ</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Утасгүй сүлжээ</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Утасгүй сүлжээ %1</translation>
    </message>
</context>
</TS>